@@ -1,5 +1,6 @@
 import scipy.optimize
 
+
 DAYS_PER_YEAR = 365.0
 
 #
@@ -13,9 +14,9 @@ def xnpv(valuesPerDate, rate):
     '''Calculate the irregular net present value.
 
     >>> from datetime import date
-    >>> valuesPerDate = {date(2019, 12, 31): -100, date(2020, 12, 31): 110)}
+    >>> valuesPerDate = {date(2019, 12, 31): -100, date(2020, 12, 31): 110}
     >>> xnpv(valuesPerDate, -0.10)
-    22.2575
+    22.257507852701295
     '''
 
     if rate == -1.0:
@@ -33,18 +34,23 @@ def xirr(valuesPerDate):
     '''Calculate the irregular internal rate of return.
 
     >>> from datetime import date
-    >>> valuesPerDate = {date(2019, 12, 31): -80005.8, date(2020, 03, 12): 65209.6)}
+    >>> valuesPerDate = {date(2019, 12, 31): -80005.8, date(2020, 3, 12): 65209.6}
     >>> xirr(valuesPerDate)
-    -0.6454
+    -0.645363882724717
     '''
     if not valuesPerDate or len(valuesPerDate) < 2:
         return None
 
+    if all(v >= 0 for v in valuesPerDate.values()):
+        return -float("inf")
+    if all(v <= 0 for v in valuesPerDate.values()):
+        return float("inf")
+
     result = None
     try:
         result = scipy.optimize.newton(lambda r: xnpv(valuesPerDate, r), 0)
     except (RuntimeError, OverflowError):    # Failed to converge?
-        result = scipy.optimize.brentq(lambda r: xnpv(valuesPerDate, r), -1.0, 1e20)
+        result = scipy.optimize.brentq(lambda r: xnpv(valuesPerDate, r), -0.999999999999999, 1e20)
 
     if not isinstance(result, complex):
         return result
